@@ -74,16 +74,28 @@ class DataStorageType(FireStoreBase):
         return dstFields
 
     def get_field(self, field_name):
+        '''
+        Returns dict of field
+        '''
+        return self.ext_storage_fields.get(field_name,None)
+    
+    def get_storage_field(self,field_name):
         '''
         Returns instance of StorageField
         '''
-        self._ext_storage_fields[field_name]
+        return self._ext_storage_fields.get(field_name,None)
 
     def get_fields(self, get_extends=True):
         # return self.get_fields_dict(get_extends)
         if get_extends:
             return self.ext_storage_fields
         return self.storage_fields
+        
+
+    def get_storage_fields(self,get_extends=True):
+        if get_extends:
+            return self._ext_storage_fields
+        return self._storage_fields
 
     def create_field_dict(self, fields):
         if isinstance(fields, dict):
@@ -117,9 +129,12 @@ class DataStorageType(FireStoreBase):
 
     @classmethod
     def get_dataStorageType(cls, storageName):
-        docRef = DataStorageType.get_firestore_client().document(
-            DataStorageType.basePath()+'/'+storageName)
-        return DataStorageType.getInstance(docRef)
+        dst = DataStorageType.DST_STORE.get(storageName,None)
+        if dst is None:
+            dstPath = DataStorageType.basePath()+'/'+storageName
+            docRef = DataStorageType.get_firestore_client().document(dstPath)
+            dst = DataStorageType.getInstance(docRef)
+        return dst
 
     @classmethod
     def getAll_DSTNames(cls):
@@ -198,7 +213,7 @@ class DataStorageType(FireStoreBase):
         for datum in update_data.get('data', []):
             fldName = datum.get('field_name', None)
             if fldName is None:
-                logger.debug("skipping field due to missing field name")
+                logging.debug("skipping field due to missing field name")
             else:
                 upDatum = {}
                 for k in datum.keys():
@@ -262,7 +277,14 @@ class DataStorageType(FireStoreBase):
 
         fields = self.get_fields(get_extends)
 
-        group_fields = jmespath.search("[?field_type == 'group']", list(fields.values()))
+        fldList = []
+        if isinstance(fields,list):
+            fldList = fields
+        
+        if isinstance(fields,dict):
+            fldList = list(fields.values())
+
+        group_fields = jmespath.search("[?field_type == 'group']", fldList)
 
         for field in group_fields:
             fields[field['field_name']] = self.__get_group_info(field,get_extends=get_extends)
@@ -381,11 +403,12 @@ class StorageField(object):
     def check_float(self, inValue):
         if inValue is None or str(inValue).strip() == "":
             return True
-        try:
-            float(inValue)
-            return True
-        except:
-            return False
+        #try:
+        #    float(inValue)
+        #    return True
+        #except:
+        #    return False
+        return DataStorageType.CheckFloat(str(inValue.strip()))
 
     def check_image(self, inValue):
         ''' Return True if it is empty or null '''
@@ -401,18 +424,18 @@ class StorageField(object):
         if isinstance(inValue, bool):
             return True
 
-        if (inValue is None or inValue.strip() == ""):
+        if (inValue is None or str(inValue).strip() == ""):
             if self.field_required:
                 return False
             else:
                 return True
 
         if (inValue is not None and len(str(inValue)) > 0):
-            if inValue.lower() == 'n/a': # saying that this field is not applicable
+            if str(inValue).lower() == 'n/a': # saying that this field is not applicable
                 return True
 
-            if (inValue == True or inValue == False or inValue.lower() == "true" or
-                    inValue.lower() == "false" or inValue == 1 or inValue == 0 or inValue == "1" or inValue == "0"):
+            if (inValue == True or inValue == False or str(inValue).lower() == "true" or
+                    str(inValue).lower() == "false" or inValue == 1 or inValue == 0 or inValue == "1" or inValue == "0"):
                 return True
             else:
                 return False
